.. change::
    :tags: bug, general
    :tickets: 8995
    :versions: 2.0.0rc1

    Fixed regression where the base compat module was calling upon
    ``platform.architecture()`` in order to detect some system properties,
    which results in an over-broad system call against the system-level
    ``file`` call that is unavailable under some circumstances, including
    within some secure environment configurations.
